FollowerMessage

Enum FollowerMessage 

pub enum FollowerMessage {
    LockStateUpdate {
        user_id: UserId,
        lock_state: LockState,
    },
    StartSession {
        user_id: UserId,
        lock_state: LockState,
    },
    HeartBeat {
        user_id: UserId,
    },
}
The messages sent from followers to the leader

Variants



LockStateUpdate

Synchronizes a user’s lock state between participants.

Fields

user_id: UserId

User whose lock state is being synchronized.

lock_state: LockState

New lock state for the user.



StartSession

A follower, upon startup should send the StartSession message to the leader to announce its presence. It also sends the lock state. The leader then should unlock if it is locked and the follower sent an unlocked state, otherwise it should not change the lock state. Subsequently, it should respond with a lockstate update.

Fields

user_id: UserId

User whose session is starting.

lock_state: LockState

Current lock state for the user.



HeartBeat

A heartbeat request to the leader every HEARTBEAT_INTERVAL.

Fields

user_id: UserId

User whose session liveness is being reported.

Implementations

Source

impl FollowerMessage

pub fn user_id(&self) -> UserId

Returns the user ID associated with the message.